==> tuia-advert-center-api-1.5.9-20180816.022344-58-sources.jar: cn/com/duiba/tuia/core/api/dto/req/qualification/ReqPageQualificationAuditDto.java <==
/**
 * Project Name:tuia-advert-center-api File Name:ReqQualificationAuditDto.java Package
 * Name:cn.com.duiba.tuia.core.api.dto.req.qualification Date:2017年11月30日下午5:51:36 Copyright (c) 2017, duiba.com.cn All
 * Rights Reserved.
 */

package cn.com.duiba.tuia.core.api.dto.req.qualification;

import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:ReqQualificationAuditDto <br/>
 * Function: 资质审核分页查询. <br/>
 * Date: 2017年11月30日 下午5:51:36 <br/>
 * 
 * @author chencheng
 * @version
 * @since JDK 1.8
 * @see
 */
public class ReqPageQualificationAuditDto extends ReqQualificationAuditDto {

    private static final long serialVersionUID = 4630486389694183566L;

    /** id集合. */
    private List<Long>        ids;

    /** 广告主账户集合. */
    private List<Long>        accountIds;

    /** 资质资源ID集合. */
    private List<Long>        qualificationIds;

    /**
     * ids.
     *
     * @return the ids
     * @since JDK 1.8
     */
    public List<Long> getIds() {
        return ids;
    }

    /**
     * ids.
     *
     * @param ids the ids to set
     * @since JDK 1.8
     */
    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    /**
     * accountIds.
     *
     * @return the accountIds
     * @since JDK 1.8
     */
    public List<Long> getAccountIds() {
        return accountIds;
    }

    /**
     * accountIds.
     *
     * @param accountIds the accountIds to set
     * @since JDK 1.8
     */
    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    /**
     * qualificationIds.
     *
     * @return the qualificationIds
     * @since JDK 1.8
     */
    public List<Long> getQualificationIds() {
        return qualificationIds;
    }

    /**
     * qualificationIds.
     *
     * @param qualificationIds the qualificationIds to set
     * @since JDK 1.8
     */
    public void setQualificationIds(List<Long> qualificationIds) {
        this.qualificationIds = qualificationIds;
    }

    public ReqPageQualificationAuditDto() {
        super();
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> tuia-advert-center-api-2.6.05-sources.jar: cn/com/duiba/tuia/core/api/dto/req/qualification/ReqPageQualificationAuditDto.java <==
/**
 * Project Name:tuia-advert-center-api File Name:ReqQualificationAuditDto.java Package
 * Name:cn.com.duiba.tuia.core.api.dto.req.qualification Date:2017年11月30日下午5:51:36 Copyright (c) 2017, duiba.com.cn All
 * Rights Reserved.
 */

package cn.com.duiba.tuia.core.api.dto.req.qualification;

import java.util.Date;
import java.util.List;

import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:ReqQualificationAuditDto <br/>
 * Function: 资质审核分页查询. <br/>
 * Date: 2017年11月30日 下午5:51:36 <br/>
 * 
 * @author chencheng
 * @version
 * @since JDK 1.8
 * @see
 */
public class ReqPageQualificationAuditDto extends ReqQualificationAuditDto {

    private static final long serialVersionUID = 4630486389694183566L;

    /** id集合. */
    private List<Long>        ids;

    /** 广告主账户集合. */
    private List<Long>        accountIds;

    /** 资质资源ID集合. */
    private List<Long>        qualificationIds;

    private Date startDate;

    private Date endDate;

    /**
     * 用户类型.
     */
    private Integer userType;

    /**
     * 代理商等级，0-一级   1-二级   2-三级   3-四级
     */
    private Integer accountLevel;

    /**
     * ids.
     *
     * @return the ids
     * @since JDK 1.8
     */
    public List<Long> getIds() {
        return ids;
    }

    /**
     * ids.
     *
     * @param ids the ids to set
     * @since JDK 1.8
     */
    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    /**
     * accountIds.
     *
     * @return the accountIds
     * @since JDK 1.8
     */
    public List<Long> getAccountIds() {
        return accountIds;
    }

    /**
     * accountIds.
     *
     * @param accountIds the accountIds to set
     * @since JDK 1.8
     */
    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    /**
     * qualificationIds.
     *
     * @return the qualificationIds
     * @since JDK 1.8
     */
    public List<Long> getQualificationIds() {
        return qualificationIds;
    }

    /**
     * qualificationIds.
     *
     * @param qualificationIds the qualificationIds to set
     * @since JDK 1.8
     */
    public void setQualificationIds(List<Long> qualificationIds) {
        this.qualificationIds = qualificationIds;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Integer getAccountLevel() {
        return accountLevel;
    }

    public void setAccountLevel(Integer accountLevel) {
        this.accountLevel = accountLevel;
    }

    public ReqPageQualificationAuditDto() {
        super();
    }

    @Override
    public Date getStartDate() {
        return startDate;
    }

    @Override
    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    @Override
    public Date getEndDate() {
        return endDate;
    }

    @Override
    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
